<!DOCTYPE html>
<html>
<head>
	<title>Tabbed Interface Example</title>
	<style>
		/* CSS styles for the tabs */
		.tabs {
			display: flex;
			list-style: none;
			margin: 0;
			padding: 0;
		}

		.tabs li {
			margin-right: 10px;
		}

		.tabs li a {
			display: block;
			padding: 10px;
			background-color: #ccc;
			color: #333;
			text-decoration: none;
		}

		.tabs li a.active {
			background-color: #333;
			color: #fff;
		}

		.tab-content {
			display: none;
		}

		.tab-content:first-child {
			display: block;
		}
	</style>
</head>
<body>
	<!-- HTML structure for the tabs -->
	<ul class="tabs">
		<li><a href="#tab1" class="active">Tab 1</a></li>
		<li><a href="#tab2">Tab 2</a></li>
		<li><a href="#tab3">Tab 3</a></li>
	</ul>

	<div class="tab-content" id="tab1" style="display: block;">
		<h2>Tab 1 Content</h2>
		<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec eget urna vel sapien lobortis blandit. Sed malesuada ex vel urna malesuada, a lobortis ex volutpat. Fusce euismod quam sit amet mi venenatis, vel ultrices eros suscipit. Fusce eget commodo lorem, vel vestibulum metus. Aenean imperdiet hendrerit faucibus. Nulla facilisi. Sed placerat, urna eget venenatis semper, est nunc ullamcorper mi, eget aliquet leo turpis in magna. Aliquam blandit leo sed magna dignissim fermentum. Sed congue erat eget nisi dignissim, eu lobortis ex auctor.</p>
	</div>

	<div id="tab2" class="tab-content">
		<h2>Tab 2 Content</h2>
		<p>Suspendisse fermentum lorem vel lectus laoreet blandit. Integer vestibulum aliquet nunc, vitae ullamcorper magna consequat non. Donec sit amet bibendum velit. Vestibulum ut dui mauris. In varius risus odio, quis hendrerit odio vehicula in. Sed ut ullamcorper urna. Duis a eros gravida, dapibus libero ut, convallis augue. Vivamus mattis turpis sed arcu tincidunt convallis. Nam at risus lacus. Sed ultrices sapien et velit vehicula tincidunt. Donec ornare ligula in tellus tincidunt dapibus. Curabitur gravida risus ac neque hendrerit, eu congue ex hendrerit. Mauris tincidunt lorem eget sem congue, ut tincidunt massa rutrum.</p>
	</div>

	<div id="tab3" class="tab-content">
		<h2>Tab 3 Content</h2>
		<p>Etiam rhoncus enim eu dolor bibendum, non ullamcorper odio interdum. Nulla eu eros sed quam dignissim mattis. Nulla dignissim sodales nisl, non mollis nisi molestie ac. Nunc consequat, ipsum
        </p></div>
        
<!-- JavaScript code to handle tab switching -->
<script>
	const tabs = document.querySelectorAll('.tabs li a');
	const tabContents = document.querySelectorAll('.tab-content');

	function switchTab(event) {
		event.preventDefault();
		// Remove 'active' class from all tabs
		tabs.forEach(tab => tab.classList.remove('active'));
		// Hide all tab contents
		tabContents.forEach(content => content.style.display = 'none');
		// Add 'active' class to clicked tab
		event.target.classList.add('active');
		// Show corresponding tab content
		const target = event.target.getAttribute('href');
		document.querySelector(target).style.display = 'block';
	}

	// Add event listener to each tab
	tabs.forEach(tab => tab.addEventListener('click', switchTab));
</script>

</body>
</html>
